@@ -1,5 +1,5 @@
-/*  Arg_parser - A POSIX/GNU command line argument parser. (C version)
-    Copyright (C) 2006, 2007, 2008, 2009, 2010 Antonio Diaz Diaz.
+/*  Arg_parser - POSIX/GNU command line argument parser. (C version)
+    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,15 +28,15 @@
 #include "carg_parser.h"
 
 
+static const char * const Program_name = "Arg_parser";
+static const char * const program_name = "arg_parser";
+static const char * const program_year = "2011";
 static const char * invocation_name = 0;
-static const char * const Program_name    = "Arg_parser";
-static const char * const program_name    = "arg_parser";
-static const char * const program_year    = "2010";
 
 
 void show_help( const char verbose )
   {
-  printf( "%s - A POSIX/GNU command line argument parser. (C version)\n", Program_name );
+  printf( "%s - POSIX/GNU command line argument parser. (C version)\n", Program_name );
   printf( "See the source file `cmain.c' to learn how to use %s in\n", Program_name );
   printf( "your own programs.\n" );
   printf( "\nUsage: %s [options]\n", invocation_name );
@@ -70,24 +70,23 @@ void show_version()
   }
 
 
-void show_error( const char * msg, const int errcode, const char help )
+void show_error( const char * const msg, const int errcode, const char help )
   {
-  if( msg && msg[0] != 0 )
+  if( msg && msg[0] )
     {
     fprintf( stderr, "%s: %s", program_name, msg );
     if( errcode > 0 ) fprintf( stderr, ": %s", strerror( errcode ) );
     fprintf( stderr, "\n" );
     }
-  if( help && invocation_name && invocation_name[0] != 0 )
-    fprintf( stderr, "Try `%s --help' for more information.\n", invocation_name );
+  if( help && invocation_name && invocation_name[0] )
+    fprintf( stderr, "Try `%s --help' for more information.\n",
+             invocation_name );
   }
 
 
-void internal_error( const char * msg )
+void internal_error( const char * const msg )
   {
-  char buf[80];
-  snprintf( buf, sizeof buf, "internal error: %s.\n", msg );
-  show_error( buf, 0, 0 );
+  fprintf( stderr, "%s: internal error: %s.\n", program_name, msg );
   exit( 3 );
   }
 
@@ -106,7 +105,7 @@ const char * optname( const int code, const struct ap_Option options[] )
   }
 
 
-int main( const int argc, const char * argv[] )
+int main( const int argc, const char * const argv[] )
   {
   char verbose = 0;
   const struct ap_Option options[] =
@@ -129,38 +128,38 @@ int main( const int argc, const char * argv[] )
   invocation_name = argv[0];
 
   if( !ap_init( &parser, argc, argv, options, 0 ) )
-    { show_error( "Memory exhausted", 0, 0 ); return 1; }
+    { show_error( "Memory exhausted.", 0, 0 ); return 1; }
   if( ap_error( &parser ) )				/* bad option */
     { show_error( ap_error( &parser ), 0, 1 ); return 1; }
 
   for( argind = 0; argind < ap_arguments( &parser ); ++argind )
     {
     const int code = ap_code( &parser, argind );
-    if( !code ) break;					// no more options
+    if( !code ) break;				/* no more options */
     switch( code )
       {
-      case 'H': break;				// example, do nothing
+      case 'H': break;				/* example, do nothing */
       case 'V': show_version(); return 0;
-      case 'a': break;				// example, do nothing
-      case 'b': break;				// example, do nothing
-      case 'c': break;				// example, do nothing
+      case 'a': break;				/* example, do nothing */
+      case 'b': break;				/* example, do nothing */
+      case 'c': break;				/* example, do nothing */
       case 'h': show_help( verbose ); return 0;
-      case 'o': break;				// example, do nothing
+      case 'o': break;				/* example, do nothing */
       case 'q': verbose = 0; break;
-      //case 'u': break;			// intentionally not caught
+      /* case 'u': break; */			/* intentionally not caught */
       case 'v': verbose = 1; break;
-      case 256: break;				// example, do nothing
+      case 256: break;				/* example, do nothing */
       default : internal_error( "uncaught option" );
       }
-    } // end process options
+    } /* end process options */
 
   for( argind = 0; argind < ap_arguments( &parser ); ++argind )
     {
     const int code = ap_code( &parser, argind );
-    const char * arg = ap_argument( &parser, argind );
-    if( code )	// option
+    const char * const arg = ap_argument( &parser, argind );
+    if( code )	/* option */
       {
-      const char * name = optname( code, options );
+      const char * const name = optname( code, options );
       if( !name[1] )
         printf( "option `-%c'", name[0] );
       else
@@ -168,7 +167,7 @@ int main( const int argc, const char * argv[] )
       if( arg[0] )
         printf( " with argument `%s'", arg );
       }
-    else	// non-option
+    else	/* non-option */
       printf( "non-option argument `%s'", arg );
     printf( "\n" );
     }
