@@ -1,5 +1,5 @@
-/*  Arg_parser - A POSIX/GNU command line argument parser. (C++ version)
-    Copyright (C) 2006, 2007, 2008, 2009, 2010 Antonio Diaz Diaz.
+/*  Arg_parser - POSIX/GNU command line argument parser. (C++ version)
+    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,15 +32,15 @@
 
 namespace {
 
+const char * const Program_name = "Arg_parser";
+const char * const program_name = "arg_parser";
+const char * const program_year = "2011";
 const char * invocation_name = 0;
-const char * const Program_name    = "Arg_parser";
-const char * const program_name    = "arg_parser";
-const char * const program_year    = "2010";
 
 
 void show_help( const bool verbose )
   {
-  std::printf( "%s - A POSIX/GNU command line argument parser. (C++ version)\n", Program_name );
+  std::printf( "%s - POSIX/GNU command line argument parser. (C++ version)\n", Program_name );
   std::printf( "See the source file `main.cc' to learn how to use %s in\n", Program_name );
   std::printf( "your own programs.\n" );
   std::printf( "\nUsage: %s [options]\n", invocation_name );
@@ -74,24 +74,24 @@ void show_version()
   }
 
 
-void show_error( const char * msg, const int errcode = 0, const bool help = false )
+void show_error( const char * const msg, const int errcode = 0, const bool help = false )
   {
-  if( msg && msg[0] != 0 )
+  if( msg && msg[0] )
     {
     std::fprintf( stderr, "%s: %s", program_name, msg );
-    if( errcode > 0 ) std::fprintf( stderr, ": %s", std::strerror( errcode ) );
+    if( errcode > 0 )
+      std::fprintf( stderr, ": %s", std::strerror( errcode ) );
     std::fprintf( stderr, "\n" );
     }
-  if( help && invocation_name && invocation_name[0] != 0 )
-    std::fprintf( stderr, "Try `%s --help' for more information.\n", invocation_name );
+  if( help && invocation_name && invocation_name[0] )
+    std::fprintf( stderr, "Try `%s --help' for more information.\n",
+                  invocation_name );
   }
 
 
-void internal_error( const char * msg )
+void internal_error( const char * const msg )
   {
-  char buf[80];
-  std::snprintf( buf, sizeof buf, "internal error: %s.\n", msg );
-  show_error( buf );
+  std::fprintf( stderr, "%s: internal error: %s.\n", program_name, msg );
   std::exit( 3 );
   }
 
@@ -131,14 +131,14 @@ int main( const int argc, const char * argv[] )
     { 256, "orphan",   Arg_parser::no    },
     {   0, 0,          Arg_parser::no    } };
 
-  Arg_parser parser( argc, argv, options );
+  const Arg_parser parser( argc, argv, options );
   if( parser.error().size() )				// bad option
     { show_error( parser.error().c_str(), 0, true ); return 1; }
 
   for( int argind = 0; argind < parser.arguments(); ++argind )
     {
     const int code = parser.code( argind );
-    if( !code ) break;					// no more options
+    if( !code ) break;				// no more options
     switch( code )
       {
       case 'H': break;				// example, do nothing
@@ -149,7 +149,7 @@ int main( const int argc, const char * argv[] )
       case 'h': show_help( verbose ); return 0;
       case 'o': break;				// example, do nothing
       case 'q': verbose = false; break;
-      //case 'u': break;			// intentionally not caught
+      // case 'u': break;			// intentionally not caught
       case 'v': verbose = true; break;
       case 256: break;				// example, do nothing
       default : internal_error( "uncaught option" );
